@@ -12,14 +12,10 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-import horizon
 from django.utils.translation import ugettext_lazy as _
-from muranodashboard import dashboard
+import horizon
 
 
 class AppCatalog(horizon.Panel):
-    name = _('Applications')
+    name = _('Browse Local')
     slug = 'catalog'
-
-
-dashboard.Murano.register(AppCatalog)
