@@ -15,8 +15,8 @@
 import json
 
 from django.conf import settings
-from django.core.urlresolvers import reverse
 from django import forms
+from django.urls import reverse
 from django.utils.translation import ugettext_lazy as _
 from horizon import exceptions
 from horizon import forms as horizon_forms
