@@ -15,9 +15,9 @@
 import json
 import sys
 
-from django.core.urlresolvers import reverse
 from django.core import validators
 from django import forms
+from django.urls import reverse
 from django.utils.translation import ugettext_lazy as _
 from horizon import exceptions
 from horizon import forms as horizon_forms
