@@ -31,12 +31,11 @@ from oslo_log import handlers
 from oslo_log import log
 from selenium.common import exceptions as exc
 from selenium import webdriver
-from selenium.webdriver.common import action_chains
 import selenium.webdriver.common.by as by
 from selenium.webdriver.support import expected_conditions as EC
 from selenium.webdriver.support import ui
 
-import config.config as cfg
+from muranodashboard.tests.functional.config import config as cfg
 from muranodashboard.tests.functional import consts
 from muranodashboard.tests.functional import utils
 
@@ -141,7 +140,7 @@ class UITestCase(testtools.TestCase):
                                              project=tenant_id,
                                              enabled=True)
         roles = cls.keystone_client.roles.list()
-        role_id = [role.id for role in roles if role.name == 'Member'][0]
+        role_id = [role.id for role in roles if role.name == 'member'][0]
         users = cls.keystone_client.users.list()
         user_id = [user.id for user in users if user.name == name][0]
         cls.keystone_client.roles.grant(role_id, user=user_id,
@@ -161,7 +160,7 @@ class UITestCase(testtools.TestCase):
     def add_user_to_project(self, project_id, user_id, user_role=None):
         if not user_role:
             roles = self.keystone_client.roles.list()
-            role_id = [role.id for role in roles if role.name == 'Member'][0]
+            role_id = [role.id for role in roles if role.name == 'member'][0]
         if not user_id:
             user_name = cfg.common.user
             users = self.keystone_client.users.list()
@@ -308,33 +307,6 @@ class UITestCase(testtools.TestCase):
         self.driver.find_element_by_xpath(consts.ConfirmDeletion).click()
         self.wait_for_alert_message()
 
-    def edit_environment(self, old_name, new_name):
-        el_td = self.driver.find_element_by_css_selector(
-            'tr[data-display="{0}"] '.format(old_name) +
-            'td[data-cell-name="name"]')
-        el_pencil = el_td.find_element_by_css_selector(
-            'button.ajax-inline-edit')
-
-        # hover to make pencil visible
-        hover = action_chains.ActionChains(self.driver).move_to_element(el_td)
-        hover.perform()
-        el_pencil.click()
-
-        # fill in inline input
-        el_inline_input = self.driver.find_element_by_css_selector(
-            'tr[data-display="{0}"] '.format(old_name) +
-            'td[data-cell-name="name"] .inline-edit-form input')
-        el_inline_input.clear()
-        el_inline_input.send_keys(new_name)
-
-        # click submit
-        el_submit = self.driver.find_element_by_css_selector(
-            'tr[data-display="{0}"] '.format(old_name) +
-            'td[data-cell-name="name"] .inline-edit-actions' +
-            ' button[type="submit"]')
-        el_submit.click()
-        # there is no alert message
-
     def select_action_for_environment(self, env_name, action):
         element_id = self.get_element_id(env_name)
         more_button = consts.More.format('environments', element_id)
