@@ -15,8 +15,8 @@
 
 import collections
 from django import forms
-import mock
 import semantic_version
+from unittest import mock
 from yaql.language import factory
 
 from muranodashboard.catalog import forms as catalog_forms
@@ -100,8 +100,8 @@ class TestService(helpers.APITestCase):
             self.assertEqual(val, getattr(service.forms[0].service, key))
 
     def test_init_service_except_value_error(self):
-        with self.assertRaisesRegexp(ValueError,
-                                     'Application section is required'):
+        with self.assertRaisesRegex(ValueError,
+                                    'Application section is required'):
             services.Service(cleaned_data={},
                              version=2,
                              fqn='io.murano.Test',
