@@ -15,8 +15,8 @@
 from django.core.files import storage
 from django import http
 from django.utils.translation import ugettext_lazy as _
+from unittest import mock
 
-import mock
 
 from horizon import exceptions as horizon_exceptions
 from muranoclient.common import exceptions as exc
@@ -276,10 +276,10 @@ class TestImportPackageWizard(helpers.APITestCase):
                 self.assertEqual(val, result[key])
 
     @mock.patch.object(views, 'exceptions')
-    @mock.patch.object(views, 'glance')
     @mock.patch.object(views, 'reverse')
+    @mock.patch.object(views, 'glance')
     @mock.patch.object(views, 'api')
-    def test_done(self, mock_api, mock_reverse, mock_glance, mock_exc):
+    def test_done(self, mock_api, mock_glance, mock_reverse, mock_exc):
         mock_storage = mock.MagicMock()
         mock_storage.get_step_data().__getitem__.return_value =\
             mock.Mock(id='test_package_id')
@@ -485,7 +485,7 @@ class TestImportPackageWizard(helpers.APITestCase):
         mock_json.loads.side_effect = ValueError('test_error_message')
         original_e = ValueError('original_error_message')
         setattr(original_e, 'details', 'error_details')
-        with self.assertRaisesRegexp(ValueError, 'original_error_message'):
+        with self.assertRaisesRegex(ValueError, 'original_error_message'):
             self.import_pkg_wizard._handle_exception(original_e)
 
     @mock.patch.object(views, 'glance')
@@ -564,8 +564,8 @@ class TestImportPackageWizard(helpers.APITestCase):
             exception.message = error_message
             mock_murano_utils.Package.from_file.side_effect = exception
 
-            with self.assertRaisesRegexp(horizon_exceptions.Http302,
-                                         None):
+            with self.assertRaisesRegex(horizon_exceptions.Http302,
+                                        None):
                 self.import_pkg_wizard.process_step(mock_form)
 
             mock_log.exception.assert_called_once_with(expected_error_message)
@@ -580,9 +580,10 @@ class TestImportPackageWizard(helpers.APITestCase):
     @mock.patch.object(views, 'LOG')
     @mock.patch.object(views, 'api')
     @mock.patch.object(views, 'muranoclient_utils')
+    @mock.patch.object(views, 'glance')
     def test_process_step_except_package_create_exception(
-            self, mock_murano_utils, mock_api, mock_log, mock_reverse,
-            mock_messages, mock_exc):
+            self, mock_glance, mock_murano_utils, mock_api, mock_log,
+            mock_reverse, mock_messages, mock_exc):
         mock_murano_utils.Package.from_file.side_effect = None
         mock_reverse.return_value = 'test_redirect'
         mock_package = mock.Mock()
@@ -637,9 +638,10 @@ class TestImportPackageWizard(helpers.APITestCase):
     @mock.patch.object(views, 'LOG')
     @mock.patch.object(views, 'api')
     @mock.patch.object(views, 'muranoclient_utils')
+    @mock.patch.object(views, 'glance')
     def test_process_step_except_http_conflict(
-            self, mock_murano_utils, mock_api, mock_log, mock_reverse,
-            mock_messages, mock_exc):
+            self, mock_glance, mock_murano_utils, mock_api, mock_log,
+            mock_reverse, mock_messages, mock_exc):
         mock_murano_utils.Package.from_file.side_effect = None
         mock_reverse.return_value = 'test_redirect'
 
@@ -690,9 +692,10 @@ class TestImportPackageWizard(helpers.APITestCase):
     @mock.patch.object(views, 'LOG')
     @mock.patch.object(views, 'api')
     @mock.patch.object(views, 'muranoclient_utils')
+    @mock.patch.object(views, 'glance')
     def test_process_step_except_http_internal_server_error(
-            self, mock_murano_utils, mock_api, mock_log, mock_reverse,
-            mock_exc):
+            self, mock_glance, mock_murano_utils, mock_api, mock_log,
+            mock_reverse, mock_exc):
         mock_murano_utils.Package.from_file.side_effect = None
         mock_reverse.return_value = 'test_redirect'
         mock_package = mock.Mock()
@@ -732,9 +735,10 @@ class TestImportPackageWizard(helpers.APITestCase):
     @mock.patch.object(views, 'LOG')
     @mock.patch.object(views, 'api')
     @mock.patch.object(views, 'muranoclient_utils')
+    @mock.patch.object(views, 'glance')
     def test_process_step_except_http_exception(
-            self, mock_murano_utils, mock_api, mock_log, mock_dashboard_utils,
-            mock_reverse, mock_exc):
+            self, mock_glance, mock_murano_utils, mock_api, mock_log,
+            mock_dashboard_utils, mock_reverse, mock_exc):
         mock_murano_utils.Package.from_file.side_effect = None
         mock_reverse.return_value = 'test_redirect'
         mock_package = mock.Mock()
@@ -848,7 +852,8 @@ class TestImportBundleWizard(helpers.APITestCase):
 
     @mock.patch.object(views, 'api')
     @mock.patch.object(views, 'muranoclient_utils')
-    def test_process_step(self, mock_murano_utils, mock_api):
+    @mock.patch.object(views, 'glance')
+    def test_process_step(self, mock_glance, mock_murano_utils, mock_api):
         mock_bundle = mock.Mock()
         mock_bundle.package_specs.return_value = [
             {'Name': 'foo_spec', 'Version': '1.0.0', 'Url': 'www.foo.com'},
@@ -915,7 +920,7 @@ class TestImportBundleWizard(helpers.APITestCase):
         for exception, expected_error_message in errors:
             mock_murano_utils.Bundle.from_file.side_effect = exception
 
-            with self.assertRaisesRegexp(horizon_exceptions.Http302, None):
+            with self.assertRaisesRegex(horizon_exceptions.Http302, None):
                 self.import_bundle_wizard.process_step(mock_form)
 
             mock_log.exception.assert_called_once_with(expected_error_message)
@@ -956,8 +961,10 @@ class TestImportBundleWizard(helpers.APITestCase):
     @mock.patch.object(views, 'LOG')
     @mock.patch.object(views, 'api')
     @mock.patch.object(views, 'muranoclient_utils')
+    @mock.patch.object(views, 'glance')
     def test_process_step_except_http_conflict(
-            self, mock_murano_utils, mock_api, mock_log, mock_messages):
+            self, mock_glance, mock_murano_utils, mock_api, mock_log,
+            mock_messages):
         mock_form = mock.Mock(
             cleaned_data={'import_type': 'by_url', 'url': 'foo_url'})
         mock_bundle = mock.Mock()
@@ -991,9 +998,10 @@ class TestImportBundleWizard(helpers.APITestCase):
     @mock.patch.object(views, 'api')
     @mock.patch.object(views, 'muranodashboard_utils')
     @mock.patch.object(views, 'muranoclient_utils')
+    @mock.patch.object(views, 'glance')
     def test_process_step_except_http_exception(
-            self, mock_murano_utils, mock_dashboard_utils, mock_api, mock_log,
-            mock_messages):
+            self, mock_glance, mock_murano_utils, mock_dashboard_utils,
+            mock_api, mock_log, mock_messages):
         mock_form = mock.Mock(
             cleaned_data={'import_type': 'by_url', 'url': 'foo_url'})
         mock_bundle = mock.Mock()
@@ -1028,8 +1036,10 @@ class TestImportBundleWizard(helpers.APITestCase):
     @mock.patch.object(views, 'LOG')
     @mock.patch.object(views, 'api')
     @mock.patch.object(views, 'muranoclient_utils')
+    @mock.patch.object(views, 'glance')
     def test_process_step_except_package_create_exception(
-            self, mock_murano_utils, mock_api, mock_log, mock_messages):
+            self, mock_glance, mock_murano_utils, mock_api, mock_log,
+            mock_messages):
         mock_form = mock.Mock(
             cleaned_data={'import_type': 'by_url', 'url': 'foo_url'})
         mock_bundle = mock.Mock()
